@@ -1,31 +1,50 @@
 # -*- coding:utf-8 -*-
 from django.utils.translation import ugettext
 
+KB = 1024  # bytes
+MB = 1024 * KB  # kb
+
+GENDER_UNDEFINED = 'I'
 GENDER_MALE = 'M'
 GENDER_FEMALE = 'F'
 GENDER_CONFUSED = 'W'
 GENDER_CHOICES = (
+    (GENDER_UNDEFINED, '???'),
     (GENDER_MALE, ugettext('Male')),
     (GENDER_FEMALE, ugettext('Female')),
     (GENDER_CONFUSED, ugettext("Won't tell"))
 )
 
-# plain text, bbcode, markdown, textile, restructuredtext, plain html
-MARKUP_PLAIN = 0
-MARKUP_BBCODE = 1
-MARKUP_MARKDOWN = 2
-MARKUP_TEXTILE = 3
-MARKUP_RST = 4
-MARKUP_HTML = 5
-MARKUP_CHOICES = (
-    (MARKUP_PLAIN, 'Plain text'),
-    (MARKUP_BBCODE, 'BBCode'),
-    (MARKUP_MARKDOWN, 'Markdown'),
-    (MARKUP_TEXTILE, 'Textile'),
-    (MARKUP_RST, 'reStructuredText'),
-    (MARKUP_HTML, 'Plain HTML'),
+BBCODE, RST, MARKDOWN, TEXTILE, PLAIN_HTML, PLAIN_TEXT = 0, 1, 2, 3, 4, 5
+
+TEXT_FORMAT_CHOICES = (
+    (BBCODE, 'BBcode'),
+    (RST, 'reStructuredText'),
+    (MARKDOWN, 'Markdown'),
+    (TEXTILE, 'Textile'),
+    (PLAIN_HTML, 'Plain HTML'),
+    (PLAIN_TEXT, 'Plain text'),
 )
 
+# plain text, bbcode, markdown, textile, restructuredtext, plain html
+MARKUP_CHOICES = (
+    (PLAIN_TEXT, 'Plain text'),
+    (BBCODE, 'BBCode'),
+    (MARKDOWN, 'Markdown'),
+    (TEXTILE, 'Textile'),
+    (RST, 'reStructuredText'),
+    (PLAIN_HTML, 'Plain HTML'),
+)
+
+MARKUP_EDITORS = {
+    PLAIN_TEXT: 'default',
+    BBCODE: 'bbcode',
+    MARKDOWN: 'markdown',
+    TEXTILE: 'textile',
+    RST: 'rest',
+    PLAIN_HTML: 'html',
+}
+
 TRANSLATE_MARKUP = {}
 
 for code, txt in MARKUP_CHOICES:
@@ -36,7 +55,7 @@ LIKES, DISLIKES = 1, -1
 RATING_CHOICES = (
     (DISLIKES, 'Dislikes'),
     (LIKES, 'Liked'),
-    )
+)
 
 # thread status
 # thread is open -> can view, *edit and reply
@@ -90,15 +109,4 @@ NICK_CH = (
     (NICK_MEDIUM, ugettext('Padawan')),
     (NICK_HIGH, ugettext('Jedi')),
     (NICK_MASTER, ugettext('Lord Siph')),
-    )
-
-BBCODE, REST, MARKDOWN, TEXTILE, PLAIN_HTML, PLAIN_TEXT = 0, 1, 2, 3, 4, 5
-
-TEXT_FORMAT_CHOICES = (
-    (BBCODE, 'BBcode'),
-    (REST, 'reStructuredText'),
-    (MARKDOWN, 'Markdown'),
-    (TEXTILE, 'Textile'),
-    (PLAIN_HTML, 'Plain HTML'),
-    (PLAIN_TEXT, 'Plain text'),
-    )
\ No newline at end of file
+)
\ No newline at end of file
