@@ -48,6 +48,7 @@ class ReplyForm(forms.ModelForm):
     def __init__(self, *args, **kw):
         super(ReplyForm, self).__init__(*args, **kw)
         self.fields['message'].required = True
+        self.fields['message'].widget.attrs['class'] = 'markitup'
 
     def save(self, author, forum, thread, commit=True):
         reply = super(ReplyForm, self).save(commit=False)
@@ -117,15 +118,6 @@ class ProfileForm(forms.ModelForm):
         fields = ['gender', 'nickname', 'avatar', 'message']
         exclude = ['user', 'flag', 'reputation', 'threads_counter', 'replies_counter']
 
-    def save(self, user, commit=True):
-        profile = super(ProfileForm, self).save(commit=False)
-        profile.user = user
-
-        if commit:
-            profile.save()
-
-        return profile
-
 
 class RateForm(forms.ModelForm):
     def save(self, author, reply, **kw):
